package util.sql;

import org.apache.log4j.Category;

/**
 * An update processor that doesn't care how many rows were updated.  Just logs the result.
 * 
 * @author Ryan Daigle
 * @version 1.0
 * @since 12/3/2001
 */
public class ComplacentUpdateProcessor implements UpdateProcessor {

    /**
     * Logging category for this class
     */
    private static Category cat = Category.getInstance(ComplacentUpdateProcessor.class);

    /**
     * The singleton instance of this class.
     */
    private static UpdateProcessor thisProcessor;

    /**
     * Default constructor.  Private so no outside instantiation.
     */
    private ComplacentUpdateProcessor() {
        //Private so no outside instantiation
    }

    /**
     * Get an instance of this update processor.
     * 
     * @return an instance of this update processor
     */
    public static UpdateProcessor getInstance() {
        if(thisProcessor == null) {
            thisProcessor = new ComplacentUpdateProcessor();
        }
        return thisProcessor;
    }

    /**
     * Takes the number of rows that were updated as a result of a sql update and do whatever
     * you want with it.
     * <p>
     * In this case, it merely logs how many rows were updated.
     * 
     * @param rows   the number of rows updated
     * @exception SQLException
     */
    public void process(int rows) {
        cat.debug("There were " + rows + " rows updated as a result of this update.");
    }
}

/*
 * $Log: ComplacentUpdateProcessor.java,v $
 * Revision 1.1  2002/03/19 02:56:18  ryan
 * Initial commit of util.sql classes for JavaWorld article.
 *
 * Revision 1.1  2001/12/04 16:40:55  rdaigle
 * First versions of the new SQL architecture, which handles ALL connection,
 * statement and execution details.  Pretty damn sweet if I do say so myself.
 * There still remains some stuff to do, such as adding overloaded methods
 * for conveniance, and actually converting all common adapters to use the
 * new architecture.
 *
 */
