package util.sql;

import java.sql.Connection;
import java.sql.DriverManager;
import org.apache.log4j.Category;

/**
 * Class to retrieve database connections.
 * <I>Warning:</I> This class is only for testing purposes!  It retrieves a raw connection
 * using a MySQL driver and user.password "test/test".
 * 
 * @author Ryan Daigle
 * @version 1.0
 * @since 12/03/2001
 */
public class ConnectionManager {

    /**
     * The logging category for this class.
     */
    private static Category cat = Category.getInstance(ConnectionManager.class);

	/**
	 * The username to use when retrieving a connection.
	 */
	private static final String CONN_USERNAME = "test";

	/**
	 * The password to use when retrieving a connection.
	 */
	private static final String CONN_PASSWORD = "test";

	/**
	 * The driver class to use when loading a connection.
	 */
	private static final String CONN_DRIVER_CLASS = "org.gjt.mm.mysql.Driver";

	/**
	 * The database URL
	 */
	private static final String CONN_DB_URL = "jdbc:mysql://localhost/test";

	/**
	 * Returns a connection to the database.
	 * <I>WARNING:</I> This class is only for demonstration purposes.  For real world
	 * implementations, a pool should be used as a source of connections.
	 * 
	 * @return <code>java.sql.Connection</code> to a database specified internally
	 * @exception SQLException
	 */
    public static Connection getConnection() {

		try {
			
			//Load the driver class
			Class.forName(CONN_DRIVER_CLASS);
	
			//And get a connection
			return DriverManager.getConnection(CONN_DB_URL,
											   CONN_USERNAME,
											   CONN_PASSWORD);
		} catch(Exception e) {
			String message = "Could not get a connection from " + CONN_DB_URL;
			cat.error(message, e);
			throw new DatabaseConnectionException(message);
		}
    }
}
