package util.sql;

import org.apache.log4j.Category;

/**
 * An update processor that mandates that at least one row have been updated as part of the
 * query.  Throws an exception if otherwise.
 * 
 * @author Ryan Daigle
 * @version 1.0
 * @since 12/3/2001
 */
public class MandatoryUpdateProcessor implements UpdateProcessor {

    /**
     * Logging category for this class
     */
    private static Category cat = Category.getInstance(MandatoryUpdateProcessor.class);

    /**
     * The singleton instance of this class.
     */
    private static UpdateProcessor thisProcessor;

    /**
     * Default constructor.  Private so no outside instantiation.
     */
    private MandatoryUpdateProcessor() {
        //Private so no outside instantiation
    }

    /**
     * Get an instance of this update processor.
     * 
     * @return an instance of this update processor
     */
    public static UpdateProcessor getInstance() {
        if(thisProcessor == null) {
            thisProcessor = new MandatoryUpdateProcessor();
        }
        return thisProcessor;
    }

    /**
     * Takes the number of rows that were updated as a result of a sql update and do whatever
     * you want with it.
     * <p>
     * In this case, an update is mandatory, so if no rows were updated then throw an exception.
     * 
     * @param rows   the number of rows updated
     * @exception SQLException
     */
    public void process(int rows) {
        if(rows < 1) {
            String message = "There were no rows updated as a result of this operation.";
            cat.error(message);
            throw new DatabaseUpdateException(message);
        }
    }
}