package util.sql.test;

import java.util.List;
import java.util.ArrayList;
import java.sql.SQLException;
import java.sql.ResultSet;
import util.sql.ResultProcessor;

/**
 * Result processor that will form <CODE>User</CODE> objects from the given result
 * set.
 * 
 * @author Ryan Daigle
 * @version 1.0
 * @since 3/20/2002
 */
public class UserResultProcessor implements ResultProcessor {

	//Column names
	private static final String COLUMN_ID = "ID";
	private static final String COLUMN_USERNAME = "USERNAME";
	private static final String COLUMN_FIRST_NAME = "F_NAME";
	private static final String COLUMN_LAST_NAME = "L_NAME";
	private static final String COLUMN_EMAIL = "EMAIL";

    /**
     * The singleton instance of this class.
     */
    private static ResultProcessor thisProcessor;

    /**
     * Default constructor.  Private so no outside instantiation.
     */
    private UserResultProcessor() {
        //Private so no outside instantiation
    }

    /**
     * Get an instance of this result processor.
     * 
     * @return an instance of this result processor
     */
    public static ResultProcessor getInstance() {

		//Since this class is stateless, we can use a singleton
        if(thisProcessor == null) {
            thisProcessor = new UserResultProcessor();
        }
        return thisProcessor;
    }

	/**
	 * Takes a result set and munges it into whatever type of object or set of
	 * objects it should be.
	 *
	 * @param rs     The result set to traverse in forming these objects
	 *
	 * @return the object or set of objects that this result set represents
	 *
	 * @exception SQLException
	 *                   this exception that can result from mishandling of a result set.  However, the developer
	 *                   shouldn't have to worry about the overhead of handling these exceptions, so let
	 *                   it bubble up.
	 */
	public Object[] process(ResultSet rs) throws SQLException {

		//Where we will collect all returned users
		List users = new ArrayList();
		User user = null;

		//If there were results returned then process them
		while(rs.next()) {

			user = new User(rs.getInt(COLUMN_ID),
							rs.getString(COLUMN_USERNAME),
							rs.getString(COLUMN_FIRST_NAME),
							rs.getString(COLUMN_LAST_NAME),
							rs.getString(COLUMN_EMAIL));
			users.add(user);
		}

		//At this point we could check to make sure that there was at least one
		//user returned, but we'll leave for somebody else.
		return users.toArray(new User[users.size()]);
	}
}
